@@ -85,7 +85,7 @@ where
 impl<S> Router<S> {
     /// Add another route to the router.
     ///
-    /// `description` is a string of path segments separated by `/`. Each segment
+    /// `path` is a string of path segments separated by `/`. Each segment
     /// can be either concrete or a capture:
     ///
     /// - `/foo/bar/baz` will only match requests where the path is `/foo/bar/bar`.
@@ -93,7 +93,7 @@ impl<S> Router<S> {
     /// capture the first segment and store it at the key `foo`.
     ///
     /// `service` is the [`Service`] that should receive the request if the path
-    /// matches `description`.
+    /// matches `path`.
     ///
     /// # Example
     ///
@@ -122,10 +122,10 @@ impl<S> Router<S> {
     ///
     /// # Panics
     ///
-    /// Panics if `description` doesn't start with `/`.
-    pub fn route<T>(self, description: &str, svc: T) -> Router<Route<T, S>> {
+    /// Panics if `path` doesn't start with `/`.
+    pub fn route<T>(self, path: &str, svc: T) -> Router<Route<T, S>> {
         self.map(|fallback| Route {
-            pattern: PathPattern::new(description),
+            pattern: PathPattern::new(path),
             svc,
             fallback,
         })
@@ -217,9 +217,9 @@ impl<S> Router<S> {
     /// `nest`.
     ///
     /// [`OriginalUri`]: crate::extract::OriginalUri
-    pub fn nest<T>(self, description: &str, svc: T) -> Router<Nested<T, S>> {
+    pub fn nest<T>(self, path: &str, svc: T) -> Router<Nested<T, S>> {
         self.map(|fallback| Nested {
-            pattern: PathPattern::new(description),
+            pattern: PathPattern::new(path),
             svc,
             fallback,
         })
@@ -257,12 +257,11 @@ impl<S> Router<S> {
     pub fn boxed<ReqBody, ResBody>(self) -> Router<BoxRoute<ReqBody, S::Error>>
     where
         S: Service<Request<ReqBody>, Response = Response<ResBody>> + Send + 'static,
-        S::Error: Into<BoxError> + Send + Sync,
+        S::Error: Into<BoxError> + Send,
         S::Future: Send,
-        ReqBody: http_body::Body<Data = Bytes> + Send + Sync + 'static,
-        ReqBody::Error: Into<BoxError> + Send + Sync + 'static,
+        ReqBody: Send + 'static,
         ResBody: http_body::Body<Data = Bytes> + Send + Sync + 'static,
-        ResBody::Error: Into<BoxError> + Send + Sync + 'static,
+        ResBody::Error: Into<BoxError>,
     {
         self.map(|svc| {
             ServiceBuilder::new()
@@ -752,10 +751,7 @@ struct Inner {
 
 impl PathPattern {
     pub(crate) fn new(pattern: &str) -> Self {
-        assert!(
-            pattern.starts_with('/'),
-            "Route description must start with a `/`"
-        );
+        assert!(pattern.starts_with('/'), "Route path must start with a `/`");
 
         let mut capture_group_names = Vec::new();
 
@@ -765,7 +761,7 @@ impl PathPattern {
                 if let Some(key) = part.strip_prefix(':') {
                     capture_group_names.push(Bytes::copy_from_slice(key.as_bytes()));
 
-                    Cow::Owned(format!("(?P<{}>[^/]*)", key))
+                    Cow::Owned(format!("(?P<{}>[^/]+)", key))
                 } else {
                     Cow::Borrowed(part)
                 }
@@ -1110,4 +1106,33 @@ mod tests {
             route_spec
         );
     }
+
+    #[test]
+    fn traits() {
+        use crate::tests::*;
+
+        assert_send::<Router<()>>();
+        assert_sync::<Router<()>>();
+
+        assert_send::<Route<(), ()>>();
+        assert_sync::<Route<(), ()>>();
+
+        assert_send::<EmptyRouter<NotSendSync>>();
+        assert_sync::<EmptyRouter<NotSendSync>>();
+
+        assert_send::<BoxRoute<(), ()>>();
+        assert_sync::<BoxRoute<(), ()>>();
+
+        assert_send::<Layered<()>>();
+        assert_sync::<Layered<()>>();
+
+        assert_send::<Nested<(), ()>>();
+        assert_sync::<Nested<(), ()>>();
+
+        assert_send::<CheckInfallible<()>>();
+        assert_sync::<CheckInfallible<()>>();
+
+        assert_send::<IntoMakeService<()>>();
+        assert_sync::<IntoMakeService<()>>();
+    }
 }
