@@ -1,9 +1,20 @@
 use bytes::Bytes;
+use pin_project_lite::pin_project;
+use std::ops::Deref;
 
 /// A string like type backed by `Bytes` making it cheap to clone.
 #[derive(Clone, Debug, PartialEq, Eq, Hash)]
 pub(crate) struct ByteStr(Bytes);
 
+impl Deref for ByteStr {
+    type Target = str;
+
+    #[inline]
+    fn deref(&self) -> &Self::Target {
+        self.as_str()
+    }
+}
+
 impl ByteStr {
     pub(crate) fn new<S>(s: S) -> Self
     where
@@ -18,3 +29,11 @@ impl ByteStr {
         std::str::from_utf8(&self.0).unwrap()
     }
 }
+
+pin_project! {
+    #[project = EitherProj]
+    pub(crate) enum Either<A, B> {
+        A { #[pin] inner: A },
+        B { #[pin] inner: B },
+    }
+}
